==> haskell-system-fileio-0.3.16.3-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-system-fileio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: system-fileio
version: 0.3.16.3
id: system-fileio-0.3.16.3-1AX8fnJlhIS16OAZu2n7aY
key: system-fileio-0.3.16.3-1AX8fnJlhIS16OAZu2n7aY
license: MIT
maintainer: FP Complete <michael@fpcomplete.com>
stability: experimental
homepage: https://github.com/fpco/haskell-filesystem
synopsis: Consistent filesystem interaction across GHC versions (deprecated)
description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx
category: System
author: John Millikin <jmillikin@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Filesystem
abi: ed483908f9819f319f0089c6dd5951ba
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/system-fileio-0.3.16.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/system-fileio-0.3.16.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/system-fileio-0.3.16.3
hs-libraries: HSsystem-fileio-0.3.16.3-1AX8fnJlhIS16OAZu2n7aY
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    system-filepath-0.4.13.4-1SCOVWlmVKv3tFcatX70u1
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj time-1.8.0.2 unix-2.7.2.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             system-filepath-0.4.13.4-1SCOVWlmVKv3tFcatX70u1=6bef6c2c5c0070d150805fc1f9f8b1de
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             unix-2.7.2.2=1e3caa57de79efd01f1c7566785dcafa
haddock-interfaces: /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock
haddock-html: /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-system-fileio-0.3.16.3-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-system-fileio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: system-fileio
version: 0.3.16.3
id: system-fileio-0.3.16.3-4BoQEVq39n0KyObJ85HJCq
key: system-fileio-0.3.16.3-4BoQEVq39n0KyObJ85HJCq
license: MIT
maintainer: FP Complete <michael@fpcomplete.com>
stability: experimental
homepage: https://github.com/fpco/haskell-filesystem
synopsis: Consistent filesystem interaction across GHC versions (deprecated)
description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx
category: System
author: John Millikin <jmillikin@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Filesystem
abi: b2d4acd489d4d6d3551c11f6c8f30bf0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/system-fileio-0.3.16.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/system-fileio-0.3.16.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/system-fileio-0.3.16.3
hs-libraries: HSsystem-fileio-0.3.16.3-4BoQEVq39n0KyObJ85HJCq
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    system-filepath-0.4.14-ETPlR1qpo7G81AFwvpRqut
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj time-1.8.0.2 unix-2.7.2.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             system-filepath-0.4.14-ETPlR1qpo7G81AFwvpRqut=575eb0ba6f371b466103607dbcc0a01c
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             unix-2.7.2.2=1e3caa57de79efd01f1c7566785dcafa
haddock-interfaces: /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock
haddock-html: /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
